#
# spec file for package libsamplerate
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libsamplerate
Version:        0.2.2
Release:        3.3
Summary:        A Sample Rate Converter Library
License:        BSD-2-Clause
Group:          Development/Libraries/C and C++
URL:            https://libsndfile.github.io/libsamplerate/
Source0:        https://github.com/libsndfile/libsamplerate/releases/download/%{version}/libsamplerate-%{version}.tar.xz
Source1:        baselibs.conf
# PATCH-FEATURE-OPENSUSE -- Make build reproducible
Patch0:         libsamplerate-0.2.1-reproducible.patch
BuildRequires:  automake
BuildRequires:  fftw3-devel
BuildRequires:  libsndfile-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig

%description
Secret Rabbit Code (aka libsamplerate) is a Sample Rate Converter for
audio. One example of where such a thing would be useful is in
converting audio from the CD sample rate of 44.1kHz to the 48kHz sample
rate used by DAT players.

SRC is capable of arbitrary and time varying conversions; from
downsampling by a factor of 12 to upsampling by the same factor.  The
conversion ratio can also vary with time for speeding up and slowing
down effects.

%package -n libsamplerate0
Summary:        A Sample Rate Converter Library
Group:          System/Libraries
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}
Obsoletes:      libsamplerate-progs < %{version}

%description -n libsamplerate0
Secret Rabbit Code (aka libsamplerate) is a Sample Rate Converter for
audio. One example of where such a thing would be useful is in
converting audio from the CD sample rate of 44.1kHz to the 48kHz sample
rate used by DAT players.

SRC is capable of arbitrary and time varying conversions; from
downsampling by a factor of 12 to upsampling by the same factor.  The
conversion ratio can also vary with time for speeding up and slowing
down effects.

%package devel
Summary:        Include Files and Libraries mandatory for Development
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libsamplerate0 = %{version}

%description devel
This package contains all necessary include files and libraries needed
to develop applications that require these.

%prep
%autosetup -p1

%build
autoreconf -fvi
%configure
profiledir=.tmp.libsamplerateprofile

%make_build CFLAGS="%{optflags} %{cflags_profile_generate}=$profiledir"
%make_build check
%make_build clean
%make_build CFLAGS="%{optflags} %{cflags_profile_feedback}=$profiledir"

%check
%make_build check

%install
%make_install
install -d %{buildroot}%{_defaultdocdir}/
mv %{buildroot}/usr/share/doc/libsamplerate %{buildroot}%{_defaultdocdir}/libsamplerate
# remove unneeded files
find %{buildroot} -type f -name "*.la" -delete -print

%post -n libsamplerate0 -p /sbin/ldconfig
%postun -n libsamplerate0 -p /sbin/ldconfig

%files -n libsamplerate0
%license COPYING
%doc AUTHORS
%{_libdir}/libsamplerate.so.0*

%files devel
%doc ChangeLog
%{_defaultdocdir}/libsamplerate
%{_libdir}/libsamplerate.so
%{_includedir}/samplerate.h
%{_libdir}/pkgconfig/samplerate.pc

%changelog
* Fri Sep 20 2024 Bernhard Wiedemann <bwiedemann@suse.com>
- Use a constant profile dir for reproducible builds (boo#1062303)
* Fri Mar  1 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Sat Oct 16 2021 Dirk Müller <dmueller@suse.com>
- update to 0.2.2:
  * Fix CMake overlinking for examples (#146)
  * Switch to GCC's visibility for hiding more implementation details
  * Check GNU ld instead of gcc for exported symbols control logic in configure.ac
  * Disable static builds using Autotools by default.
  * ABI version incompatibility between Autotools and CMake build on Apple platforms.
  * Fixes and improvements for CMake build system.
  * Fixes and improvements for Autotools build system.
  * Switch to .xz over .bz2 for release tarballs.
  * Minor bug fixes and updates.
* Sun Jan 24 2021 Dirk Müller <dmueller@suse.com>
- update to 0.2.1:
  * Add src_clone() function to clone a SRC_STATE* handle
  * Cleanup Autotools build system.
  * Require C99 compiler
  * Add missing src_get_channels() export to windows def file
  * Fix macOS compile errors and modernize audio api on that platform
  * Add Octave scripts to generate filter coefficients
  * Fix two potential undefined behaviours
  * Fix a buffer out-of-bounds read error in src/src_sinc.c
  * Improve multichan_throughput_test
  * Replace buggy implementation of Duffs device by regular loop
  * Fix CMake generated shared library ABI compliance with Autotools build
  * Move site to new URL: http://libsndfile.github.io/libsamplerate/
  * Convert documentation pages from HTML to Markdown
  * Move sndfile-resample to sndfile-tools package
  - > drop progs subpackage
- drop libsamplerate-0.1.9-reproducible.patch
- add libsamplerate-0.2.1-reproducible.patch
* Tue Jan  9 2018 bwiedemann@suse.com
- Add libsamplerate-0.1.9-reproducible.patch to disable throughput
  test to make builds reproducible in spite of Profile Guided Optimizations
* Sat Sep 30 2017 jengelh@inai.de
- Rectify RPM groups.
* Mon Apr 24 2017 tiwai@suse.de
- Add missing provides/obsoletes for the old libsamplerate package
* Tue Oct 25 2016 tom.mbrt@googlemail.com
- update to version 0.1.9 (2016-09-23)
  * Relicense under 2 clause BSD license.
  * Minor bug fixes and upates.
- remove 0001-src-src_sinc.c-Fix-a-read-beyond-end-of-coefficent-a.patch
  since it was fixed upstream
* Mon Feb 23 2015 rguenther@suse.com
- Avoid running configure twice and using -fprofile-generate or
  - fprofile-use for compiling configure tests when profiling.
* Tue Aug 26 2014 fcrozat@suse.com
- Add obsoletes/provides to baselibs.conf.
* Sat May 18 2013 dmueller@suse.com
- disable profiling also on aarch64
* Tue Apr 16 2013 crrodriguez@opensuse.org
- 0001-src-src_sinc.c-Fix-a-read-beyond-end-of-coefficent-a.patch
  from upstream, fix off-by-one bug found by gcc 4.8 address sanitizer.
* Wed Aug  1 2012 adrian@suse.de
- disable profiling on arm
* Sat May  5 2012 crrodriguez@opensuse.org
- build with profiling rnabled
* Tue Mar  6 2012 saschpe@suse.de
- Adhere to shared library packaging policy
* Sun Mar  4 2012 reddwarf@opensuse.org
- update to version 0.1.8
  * Minor bug fixes and updates.
- drop all patches, not needed in new upstream version
- run spec-cleaner
* Tue Nov 22 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Sat Aug  6 2011 meissner@suse.de
- disable quilt usage, as it extends the build chain quite some
* Wed Dec  8 2010 cristian.rodriguez@opensuse.org
- Import debian fixes, this fix:
  * The test suite so we can run make check
  * src_simple() causes a crash with certain inputs
* Sun Jun  6 2010 cristian.rodriguez@opensuse.org
- update to version 0.1.7
  * Fix a segfault which occurs when memcpy is passed a bad length parameter.
  * Minor bug fix in test suite (account for rounding error on x86_64).
  * Optimisation resulting dramatic throughput improvements.
* Fri Dec 18 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Thu Apr 23 2009 tiwai@suse.de
- added progs sub-packabe (bnc#443543)
* Wed Nov 12 2008 tiwai@suse.de
- fixed misc build errors: remove unnecessary Makefiles in doc and
  fixed package summary
* Tue Nov 11 2008 dominique-rpm@leuenberger.net
- Update to version 0.1.4:
  * Fix buffer overrrun bug at extreme low conversion ratios.
  Thanks to Russell O'Connor for the report.
  (bnc# 443794 / CVE-2008-5008 )
* Wed Jun 18 2008 tiwai@suse.de
- updated to version 0.1.3:
  * Huge quality improvements to two best SINC based converters
- fix post and postun scripts
* Wed Jun  4 2008 ro@suse.de
- added baselibs.conf (for alsa-plugins-samplerate)
* Mon Apr 16 2007 tiwai@suse.de
- follow library package policy
  * move docs to devel package
  * remove static library
* Mon Apr 16 2007 schwab@suse.de
- Fix quoting in autoconf macros.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 21 2005 tiwai@suse.de
- updated to version 0.1.2.
* Thu Aug  5 2004 tiwai@suse.de
- updated to version 0.1.1.
* Tue Jan 13 2004 tiwai@suse.de
- build as non-root.
* Fri Jun  6 2003 tiwai@suse.de
- updated to version 0.0.15.
- fixed the file list.
* Thu Mar 27 2003 tiwai@suse.de
- added the missing src_set_ratio in version list.
* Fri Jan 17 2003 tiwai@suse.de
- added %%run_ldconfig to %%post.
* Thu Jan 16 2003 tiwai@suse.de
- initial version: 0.0.14.
